from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

long_description = (here / "README.md").read_text(encoding="utf-8")

setup(
    name="sekv-e",
    version="1.0.0.dev1",

    description="SEKV-E is a Python-based parameters extractor for the simplified EKV model.",
    long_description=long_description,
    long_description_content_type="text/markdown",

    url="https://gitlab.com/moscm/sekv-e",
    author="Hung-Chi Han, Vicente Carbon",
    author_email="hung.han@epfl.ch",
    license='MIT',

    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords="ekv, sekv, extractor, modeling, MOSFET",

    packages=find_packages(include=['sekve']),
    install_requires=[
        "argon2-cffi==21.3.0",
        "argon2-cffi-bindings==21.2.0",
        "asttokens==2.0.5",
        "attrs==21.4.0",
        "backcall==0.2.0",
        "beautifulsoup4==4.11.1",
        "bleach==4.1.0",
        "Bottleneck==1.3.4",
        "certifi==2022.6.15",
        "cffi==1.15.0",
        "colorama==0.4.4",
        "cycler==0.11.0",
        "debugpy==1.5.1",
        "decorator==5.1.1",
        "defusedxml==0.7.1",
        "entrypoints==0.4",
        "executing==0.8.3",
        "fastjsonschema==2.15.1",
        "fonttools==4.25.0",
        "ipykernel==6.9.1",
        "ipython==8.2.0",
        "ipython-genutils==0.2.0",
        "ipywidgets==7.6.5",
        "jedi==0.18.1",
        "Jinja2==3.0.3",
        "jsonschema==4.4.0",
        "jupyter==1.0.0",
        "jupyter-client==7.2.2",
        "jupyter-console==6.4.3",
        "jupyter-core==4.9.2",
        "jupyterlab-pygments==0.1.2",
        "jupyterlab-widgets==1.0.0",
        "kiwisolver==1.4.2",
        "MarkupSafe==2.0.1",
        "matplotlib==3.5.1",
        "matplotlib-inline==0.1.2",
        "mistune==0.8.4",
        "mkl-fft==1.3.1",
        "mkl-random==1.2.2",
        "mkl-service==2.4.0",
        "munkres==1.1.4",
        "nbclient==0.5.13",
        "nbconvert==6.4.4",
        "nbformat==5.3.0",
        "nest-asyncio==1.5.5",
        "notebook==6.4.8",
        "numexpr==2.8.1",
        "numpy==1.22.3",
        "packaging==21.3",
        "pandas==1.4.2",
        "pandocfilters==1.5.0",
        "parso==0.8.3",
        "pickleshare==0.7.5",
        "Pillow==9.0.1",
        "pip==22.1.2",
        "prometheus-client==0.13.1",
        "prompt-toolkit==3.0.20",
        "pure-eval==0.2.2",
        "pycparser==2.21",
        "Pygments==2.11.2",
        "pyparsing==3.0.4",
        "pyrsistent==0.18.0",
        "python-dateutil==2.8.2",
        "pytz==2022.1",
        "pywin32==302",
        "pywinpty==2.0.2",
        "pyzmq==22.3.0",
        "qtconsole==5.3.0",
        "QtPy==2.0.1",
        "scipy==1.7.3",
        "Send2Trash==1.8.0",
        "setuptools==61.2.0",
        "sip==6.6.2",
        "six==1.16.0",
        "soupsieve==2.3.1",
        "stack-data==0.2.0",
        "terminado==0.13.1",
        "testpath==0.5.0",
        "tornado==6.1",
        "traitlets==5.1.1",
        "typing_extensions==4.1.1",
        "wcwidth==0.2.5",
        "webencodings==0.5.1",
        "wheel==0.37.1",
        "widgetsnbextension==3.5.2",
        "wincertstore==0.2"
    ],
    python_requires=">=3.7, <4",
    package_data={
        "env": ["environment.yaml"],
    },

    project_urls={  # Optional
        "Git": "https://gitlab.com/moscm/sekv-e",
    },
)